@@ -15,8 +15,8 @@
  * along with this program; If not, see http://www.gnu.org/licenses/.
  */
 
-#ifndef GLOGGER_H
-#define GLOGGER_H
+#ifndef G_LOGGER_H
+#define G_LOGGER_H
 
 #include <glib.h>
 
@@ -24,6 +24,8 @@
 extern "C" {
 #endif
 
+extern int foreground;
+
 void g_logger(int log_level, const char *format, ...);
 
 const char *g_logger_level_name(int log_level);
