@@ -24,8 +24,14 @@
 extern "C" {
 #endif
 
-
-enum queueEnum {queueRequest, queueRequestPrio, queueRequestBulk, queueDirty, queueRender,  queueDuplicate, queueRequestLow};
+enum queueEnum { queueRequest,
+		 queueRequestPrio,
+		 queueRequestBulk,
+		 queueDirty,
+		 queueRender,
+		 queueDuplicate,
+		 queueRequestLow
+	       };
 
 struct item {
 	struct item *next;
@@ -38,11 +44,11 @@ struct item {
 	enum queueEnum originatedQueue;
 };
 
-//int render(Map &m, int x, int y, int z, const char *filename);
+// int render(Map &m, int x, int y, int z, const char *filename);
 void *render_thread(void *);
 struct item *fetch_request(void);
 void delete_request(struct item *item);
-void render_init(const char *plugins_dir, const char* font_dir, int font_recurse);
+void render_init(const char *plugins_dir, const char *font_dir, int font_recurse);
 
 #ifdef __cplusplus
 }
