@@ -1871,6 +1871,7 @@ static const char *_add_tile_config(cmd_parms *cmd,
 
 	int attribution_len = strnlen(attribution, PATH_MAX);
 	int baseuri_len = strnlen(baseuri, PATH_MAX);
+	int cors_len = strnlen(cors, PATH_MAX);
 	int hostnames_len = 1;
 	int server_alias_len = strnlen(server_alias, PATH_MAX);
 	int tile_dir_len = strnlen(tile_dir, PATH_MAX);
@@ -1887,6 +1888,11 @@ static const char *_add_tile_config(cmd_parms *cmd,
 		baseuri = apr_psprintf(cmd->pool, "%s/", baseuri);
 	}
 
+	// If cors is empty, set it to NULL
+	if (cors_len == 0) {
+		cors = NULL;
+	}
+
 	// If server_alias is set, increment hostnames_len
 	if (server_alias_len > 0) {
 		hostnames_len++;
@@ -1954,7 +1960,7 @@ static const char *_add_tile_config(cmd_parms *cmd,
 
 static const char *add_tile_mime_config(cmd_parms *cmd, void *mconfig, const char *baseuri, const char *name, const char *fileExtension)
 {
-	char *cors = NULL;
+	char *cors = "";
 	char *mimeType = "image/png";
 
 	if (strcmp(fileExtension, "js") == 0) {
