@@ -23,17 +23,20 @@
 #include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <strings.h>
 #include <sys/socket.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/un.h>
 #include <unistd.h>
 
-#include "render_submit_queue.h"
-#include "sys_utils.h"
+#include "g_logger.h"
 #include "protocol.h"
 #include "protocol_helper.h"
 #include "render_config.h"
+#include "render_submit_queue.h"
+#include "sys_utils.h"
 
 static pthread_mutex_t qLock;
 static pthread_mutex_t qStatsLock;
@@ -54,7 +57,7 @@ struct speed_stat {
 	time_t time_min;
 	time_t time_max;
 	time_t time_total;
-	int    noRendered;
+	int noRendered;
 };
 
 struct speed_stats {
@@ -74,13 +77,14 @@ static void check_load(void)
 	double avg = get_load_avg();
 
 	while (avg >= maxLoad) {
-		/* printf("Load average %d, sleeping\n", avg); */
-		sleep(5);
+		int seconds = 5;
+		g_logger(G_LOG_LEVEL_DEBUG, "Load average %d, sleeping %is", avg, seconds);
+		sleep(seconds);
 		avg = get_load_avg();
 	}
 }
 
-static int process(struct protocol * cmd, int fd)
+static int process(struct protocol *cmd, int fd)
 {
 	struct timeval tim;
 	time_t t1;
@@ -91,25 +95,28 @@ static int process(struct protocol * cmd, int fd)
 	gettimeofday(&tim, NULL);
 	t1 = tim.tv_sec * 1000 + (tim.tv_usec / 1000);
 
-	//printf("Sending request\n");
+	g_logger(G_LOG_LEVEL_DEBUG, "Sending request");
+
 	if (send_cmd(cmd, fd) < 1) {
-		perror("send error");
+		g_logger(G_LOG_LEVEL_ERROR, "send error: %s", strerror(errno));
 	};
 
-	//printf("Waiting for response\n");
 	bzero(&rsp, sizeof(rsp));
 
+	g_logger(G_LOG_LEVEL_DEBUG, "Waiting for response");
+
 	ret = recv_cmd(&rsp, fd, 1);
 
 	if (ret < 1) {
 		return 0;
 	}
 
-	//printf("Got response %i\n", rsp.cmd);
+	g_logger(G_LOG_LEVEL_DEBUG, "Got response %i", rsp.cmd);
 
 	if (rsp.cmd != cmdDone) {
-		printf("rendering failed with command %i, pausing.\n", rsp.cmd);
-		sleep(10);
+		int seconds = 1;
+		g_logger(G_LOG_LEVEL_DEBUG, "Rendering not done with command %i, sleeping %is", rsp.cmd, seconds);
+		sleep(seconds);
 	} else {
 		gettimeofday(&tim, NULL);
 		t2 = tim.tv_sec * 1000 + (tim.tv_usec / 1000);
@@ -130,13 +137,13 @@ static int process(struct protocol * cmd, int fd)
 	}
 
 	if (!ret) {
-		perror("Socket send error");
+		g_logger(G_LOG_LEVEL_ERROR, "Socket send error: %s", strerror(errno));
 	}
 
 	return ret;
 }
 
-static struct protocol * fetch(void)
+static struct protocol *fetch(void)
 {
 	pthread_mutex_lock(&qLock);
 
@@ -151,7 +158,7 @@ static struct protocol * fetch(void)
 
 	// Fetch item from queue
 	if (!qHead) {
-		fprintf(stderr, "Queue failure, null qHead with %d items in list\n", qLen);
+		g_logger(G_LOG_LEVEL_CRITICAL, "Queue failure, null qHead with %d items in list", qLen);
 		exit(1);
 	}
 
@@ -167,7 +174,7 @@ static struct protocol * fetch(void)
 	pthread_cond_signal(&qCondNotFull);
 	pthread_mutex_unlock(&qLock);
 
-	struct protocol * cmd = malloc(sizeof(struct protocol));;
+	struct protocol *cmd = malloc(sizeof(struct protocol));
 
 	cmd->ver = 2;
 	cmd->cmd = cmdRenderBulk;
@@ -194,7 +201,7 @@ void enqueue(const char *xmlname, int x, int y, int z)
 	e->next = NULL;
 
 	if (!e->mapname) {
-		fprintf(stderr, "Malloc failure\n");
+		g_logger(G_LOG_LEVEL_CRITICAL, "Malloc failure");
 		exit(1);
 	}
 
@@ -204,7 +211,7 @@ void enqueue(const char *xmlname, int x, int y, int z)
 		int ret = pthread_cond_wait(&qCondNotFull, &qLock);
 
 		if (ret != 0) {
-			fprintf(stderr, "pthread_cond_wait(qCondNotFull): %s\n", strerror(ret));
+			g_logger(G_LOG_LEVEL_WARNING, "pthread_cond_wait(qCondNotFull): %s", strerror(ret));
 		}
 	}
 
@@ -233,7 +240,7 @@ int make_connection(const char *spath)
 		fd = socket(PF_UNIX, SOCK_STREAM, 0);
 
 		if (fd < 0) {
-			fprintf(stderr, "failed to create unix socket\n");
+			g_logger(G_LOG_LEVEL_CRITICAL, "failed to create unix socket");
 			exit(2);
 		}
 
@@ -241,7 +248,7 @@ int make_connection(const char *spath)
 		addr.sun_family = AF_UNIX;
 		strncpy(addr.sun_path, spath, sizeof(addr.sun_path) - 1);
 
-		if (connect(fd, (struct sockaddr *) &addr, sizeof(addr)) < 0) {
+		if (connect(fd, (struct sockaddr *)&addr, sizeof(addr)) < 0) {
 			close(fd);
 			return -1;
 		}
@@ -273,12 +280,12 @@ int make_connection(const char *spath)
 
 		snprintf(port_s, sizeof(port_s), "%u", port);
 
-		printf("Connecting to %s, port %u/tcp\n", hostname, port);
+		g_logger(G_LOG_LEVEL_DEBUG, "Connecting to %s, port %u/tcp", hostname, port);
 
 		struct protoent *protocol = getprotobyname("tcp");
 
 		if (!protocol) {
-			fprintf(stderr, "cannot find TCP protocol number\n");
+			g_logger(G_LOG_LEVEL_CRITICAL, "cannot find TCP protocol number");
 			exit(2);
 		}
 
@@ -305,7 +312,7 @@ int make_connection(const char *spath)
 		int ai = getaddrinfo(hostname, port_s, &hints, &result);
 
 		if (ai != 0) {
-			fprintf(stderr, "cannot resolve hostname %s\n", hostname);
+			g_logger(G_LOG_LEVEL_CRITICAL, "cannot resolve hostname %s", hostname);
 			exit(2);
 		}
 
@@ -323,26 +330,24 @@ int make_connection(const char *spath)
 			int name_info = getnameinfo(rp->ai_addr, rp->ai_addrlen, resolved_addr, sizeof(resolved_addr), resolved_port, sizeof(resolved_port), NI_NUMERICHOST | NI_NUMERICSERV);
 
 			if (name_info != 0) {
-				fprintf(stderr, "cannot retrieve name info: %d\n", name_info);
+				g_logger(G_LOG_LEVEL_CRITICAL, "cannot retrieve name info: %d", name_info);
 				exit(2);
 			}
 
-			fprintf(stderr, "Trying %s:%s\n", resolved_addr, resolved_port);
+			g_logger(G_LOG_LEVEL_DEBUG, "Trying %s:%s", resolved_addr, resolved_port);
 
 			if (connect(fd, rp->ai_addr, rp->ai_addrlen) == 0) {
-				printf("Connected to %s:%s\n", resolved_addr, resolved_port);
+				g_logger(G_LOG_LEVEL_DEBUG, "Connected to %s:%s", resolved_addr, resolved_port);
 				break;
 			}
-
 		}
 
 		freeaddrinfo(result);
 
 		if (rp == NULL) {
-			fprintf(stderr, "cannot connect to any address for %s\n", hostname);
+			g_logger(G_LOG_LEVEL_CRITICAL, "cannot connect to any address for %s", hostname);
 			exit(2);
 		}
-
 	}
 
 	return fd;
@@ -354,12 +359,12 @@ void *thread_main(void *arg)
 	int fd = make_connection(spath);
 
 	if (fd < 0) {
-		fprintf(stderr, "connect failed for: %s\n", spath);
+		g_logger(G_LOG_LEVEL_ERROR, "connect failed for: %s", spath);
 		return NULL;
 	}
 
 	while (1) {
-		struct protocol * cmd;
+		struct protocol *cmd;
 		check_load();
 
 		if (!(cmd = fetch())) {
@@ -367,14 +372,15 @@ void *thread_main(void *arg)
 		}
 
 		while (process(cmd, fd) < 1) {
-			fprintf(stderr, "connection to renderd lost\n");
+			g_logger(G_LOG_LEVEL_ERROR, "connection to renderd lost");
 			close(fd);
 			fd = -1;
 
 			while (fd < 0) {
-				fprintf(stderr, "sleeping for 30 seconds\n");
+				int seconds = 30;
+				g_logger(G_LOG_LEVEL_WARNING, "sleeping for %i seconds", seconds);
 				sleep(30);
-				fprintf(stderr, "attempting to reconnect\n");
+				g_logger(G_LOG_LEVEL_WARNING, "attempting to reconnect");
 				fd = make_connection(spath);
 			}
 		}
@@ -401,17 +407,17 @@ void spawn_workers(int num, const char *spath, int max_load)
 
 	qMaxLen = no_workers;
 
-	printf("Starting %d rendering threads\n", no_workers);
+	g_logger(G_LOG_LEVEL_MESSAGE, "Starting %d rendering threads", no_workers);
 	workers = calloc(sizeof(pthread_t), no_workers);
 
 	if (!workers) {
-		perror("Error allocating worker memory");
+		g_logger(G_LOG_LEVEL_CRITICAL, "Error allocating worker memory: %s", strerror(errno));
 		exit(1);
 	}
 
 	for (i = 0; i < no_workers; i++) {
 		if (pthread_create(&workers[i], NULL, thread_main, (void *)spath)) {
-			perror("Thread creation failed");
+			g_logger(G_LOG_LEVEL_CRITICAL, "Thread creation failed: %s", strerror(errno));
 			exit(1);
 		}
 	}
@@ -428,7 +434,7 @@ void print_statistics(void)
 		}
 
 		printf("Zoom %02i: min: %4.1f    avg: %4.1f     max: %4.1f     over a total of %8.1fs in %i requests\n",
-		       i, performance_stats.stat[i].time_min / 1000.0, (performance_stats.stat[i].time_total /  performance_stats.stat[i].noRendered) / 1000.0,
+		       i, performance_stats.stat[i].time_min / 1000.0, (performance_stats.stat[i].time_total / (float)performance_stats.stat[i].noRendered) / 1000.0,
 		       performance_stats.stat[i].time_max / 1000.0, performance_stats.stat[i].time_total / 1000.0, performance_stats.stat[i].noRendered);
 	}
 
@@ -450,15 +456,13 @@ void wait_for_empty_queue()
 
 void finish_workers(void)
 {
-	int i;
-
-	printf("Waiting for rendering threads to finish\n");
+	g_logger(G_LOG_LEVEL_MESSAGE, "Waiting for rendering threads to finish");
 	pthread_mutex_lock(&qLock);
 	work_complete = 1;
 	pthread_mutex_unlock(&qLock);
 	pthread_cond_broadcast(&qCondNotEmpty);
 
-	for (i = 0; i < no_workers; i++) {
+	for (int i = 0; i < no_workers; i++) {
 		pthread_join(workers[i], NULL);
 	}
 
